package cn.com.infosec.mobile.android.xlog.flattener;

import android.support.annotation.Keep;
import cn.com.infosec.mobile.android.xlog.LogLevel;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

@Keep
public class PatternFlattener implements Flattener, Flattener2 {
   private static final String PARAM = "[^{}]*";
   private static final Pattern PARAM_REGEX = Pattern.compile("\\{([^{}]*)\\}");
   private static final String PARAMETER_DATE = "d";
   private static final String PARAMETER_LEVEL_SHORT = "l";
   private static final String PARAMETER_LEVEL_LONG = "L";
   private static final String PARAMETER_TAG = "t";
   private static final String PARAMETER_MESSAGE = "m";
   static final String DEFAULT_DATE_FORMAT = "yyyy-MM-dd HH:mm:ss.SSS";
   private String pattern;
   private List<ParameterFiller> parameterFillers;

   public PatternFlattener(String pattern) {
      if (pattern != null) {
         this.pattern = pattern;
         List var2;
         this.parameterFillers = var2 = parseParameters(parsePattern(pattern));
         if (var2.size() == 0) {
            throw new IllegalArgumentException("No recognizable parameter found in the pattern " + pattern);
         }
      } else {
         throw new NullPointerException("Pattern should not be null");
      }
   }

   static List<String> parsePattern(String pattern) {
      ArrayList var1;
      var1 = new ArrayList.<init>(4);
      Matcher pattern1 = PARAM_REGEX.matcher(pattern);

      while(pattern1.find()) {
         var1.add(pattern1.group(1));
      }

      return var1;
   }

   private static List<ParameterFiller> parseParameters(List<String> parameters) {
      ArrayList var1;
      var1 = new ArrayList.<init>(parameters.size());
      Iterator parameters1 = parameters.iterator();

      while(parameters1.hasNext()) {
         ParameterFiller var2;
         if ((var2 = parseParameter((String)parameters1.next())) != null) {
            var1.add(var2);
         }
      }

      return var1;
   }

   private static ParameterFiller parseParameter(String parameter) {
      String var1;
      DateFiller var2;
      if ((var2 = parseDateParameter(var1 = "{" + parameter + "}", parameter = parameter.trim())) != null) {
         return var2;
      } else {
         LevelFiller var4;
         if ((var4 = parseLevelParameter(var1, parameter)) != null) {
            return var4;
         } else {
            TagFiller var5;
            if ((var5 = parseTagParameter(var1, parameter)) != null) {
               return var5;
            } else {
               MessageFiller parameter1;
               return (parameter1 = parseMessageParameter(var1, parameter)) != null ? parameter1 : null;
            }
         }
      }
   }

   static DateFiller parseDateParameter(String wrappedParameter, String trimmedParameter) {
      if (trimmedParameter.startsWith("d ")) {
         int var10000 = trimmedParameter.length();
         byte var2 = 2;
         if (var10000 > 2) {
            String var3 = trimmedParameter.substring(var2);
            return new DateFiller(wrappedParameter, trimmedParameter, var3);
         }
      }

      return trimmedParameter.equals("d") ? new DateFiller(wrappedParameter, trimmedParameter, "yyyy-MM-dd HH:mm:ss.SSS") : null;
   }

   static LevelFiller parseLevelParameter(String wrappedParameter, String trimmedParameter) {
      if (trimmedParameter.equals("l")) {
         return new LevelFiller(wrappedParameter, trimmedParameter, false);
      } else {
         return trimmedParameter.equals("L") ? new LevelFiller(wrappedParameter, trimmedParameter, true) : null;
      }
   }

   static TagFiller parseTagParameter(String wrappedParameter, String trimmedParameter) {
      return trimmedParameter.equals("t") ? new TagFiller(wrappedParameter, trimmedParameter) : null;
   }

   static MessageFiller parseMessageParameter(String wrappedParameter, String trimmedParameter) {
      return trimmedParameter.equals("m") ? new MessageFiller(wrappedParameter, trimmedParameter) : null;
   }

   public CharSequence flatten(int logLevel, String tag, String message) {
      return this.flatten(System.currentTimeMillis(), logLevel, tag, message);
   }

   public CharSequence flatten(long timeMillis, int logLevel, String tag, String message) {
      PatternFlattener var10000 = this;
      String var7 = this.pattern;

      for(Iterator var6 = var10000.parameterFillers.iterator(); var6.hasNext(); var7 = ((ParameterFiller)var6.next()).fill(var7, timeMillis, logLevel, tag, message)) {
      }

      return var7;
   }

   abstract static class ParameterFiller {
      String wrappedParameter;
      String trimmedParameter;

      ParameterFiller(String wrappedParameter, String trimmedParameter) {
         this.wrappedParameter = wrappedParameter;
         this.trimmedParameter = trimmedParameter;
      }

      protected abstract String fill(String var1, long var2, int var4, String var5, String var6);
   }

   static class MessageFiller extends ParameterFiller {
      MessageFiller(String wrappedParameter, String trimmedParameter) {
         super(wrappedParameter, trimmedParameter);
      }

      protected String fill(String pattern, long timeMillis, int logLevel, String tag, String message) {
         return pattern.replace(super.wrappedParameter, message);
      }
   }

   static class TagFiller extends ParameterFiller {
      TagFiller(String wrappedParameter, String trimmedParameter) {
         super(wrappedParameter, trimmedParameter);
      }

      protected String fill(String pattern, long timeMillis, int logLevel, String tag, String message) {
         return pattern.replace(super.wrappedParameter, tag);
      }
   }

   static class LevelFiller extends ParameterFiller {
      boolean useLongName;

      LevelFiller(String wrappedParameter, String trimmedParameter, boolean useLongName) {
         super(wrappedParameter, trimmedParameter);
         this.useLongName = useLongName;
      }

      protected String fill(String pattern, long timeMillis, int logLevel, String tag, String message) {
         String var7;
         if (this.useLongName) {
            var7 = super.wrappedParameter;
            return pattern.replace(var7, LogLevel.getLevelName(logLevel));
         } else {
            var7 = super.wrappedParameter;
            return pattern.replace(var7, LogLevel.getShortLevelName(logLevel));
         }
      }
   }

   static class DateFiller extends ParameterFiller {
      String dateFormat;
      private ThreadLocal<SimpleDateFormat> threadLocalDateFormat;

      DateFiller(String wrappedParameter, String trimmedParameter, String dateFormat) {
         super(wrappedParameter, trimmedParameter);
         ThreadLocal wrappedParameter1;
         ThreadLocal var10003 = wrappedParameter1 = new ThreadLocal<SimpleDateFormat>() {
            // $FF: synthetic field
            final PatternFlattener.DateFiller this$0;

            {
               this.this$0 = this$0;
            }

            protected SimpleDateFormat initialValue() {
               return new SimpleDateFormat(this.this$0.dateFormat, Locale.US);
            }
         };
         var10003.<init>();
         this.threadLocalDateFormat = var10003;
         this.dateFormat = dateFormat;

         try {
            ((SimpleDateFormat)wrappedParameter1.get()).format(new Date());
         } catch (Exception var4) {
            throw new IllegalArgumentException("Bad date pattern: " + dateFormat, var4);
         }

      }

      protected String fill(String pattern, long timeMillis, int logLevel, String tag, String message) {
         return pattern.replace(super.wrappedParameter, ((SimpleDateFormat)this.threadLocalDateFormat.get()).format(new Date(timeMillis)));
      }
   }
}
